@@ -6,6 +6,21 @@ import os.path
 import pandas as pd
 import re
 
+
+def __src(x):
+    root = os.path.dirname(__file__)
+    return os.path.abspath(os.path.join(root, x))
+
+
+def __read_file(fname):
+    with open(__src(fname), "r") as fin:
+        return "".join([e.strip() for e in fin.readlines()]).strip()
+
+
+def _version():
+    return __read_file("version.txt")
+
+
 # Command line parsing of (1) --abc and (2) --abc=def
 KWARG = re.compile("^--[a-z0-9_-]+$")
 KWARG_WITH_VALUE = re.compile("^--[a-z0-9_-]+=")
@@ -158,8 +173,10 @@ def dropna():
 
 
 def pipeout(df, sep=",", index=False, *args, **kwargs):
+    csv = df.to_csv(sep=sep, index=index, *args, **kwargs)
+    output = csv.rstrip("\n")
     try:
-        print(df.to_csv(sep=sep, index=index, *args, **kwargs))
+        print(output)
     except BrokenPipeError:
         try:
             sys.stdout.close()
@@ -508,8 +525,8 @@ def help(*args, **kwargs):
     print("       {}".format(ds))
 
 
-@register
-def open(ftype, fname, sheet=0):
+@registerx("open")
+def open_(ftype, fname, sheet=0):
     """Use a reader to open a file.
 
     Open ftype file with name fname and stream out.
@@ -715,6 +732,9 @@ def main():
     if len(sys.argv) < 2:
         exit("Usage: ph command [args]\n       ph help")
     cmd = sys.argv[1]
+    if cmd in ("-v", "--version"):
+        print(_version())
+        exit()
     if cmd not in COMMANDS:
         exit("Unknown command {}.".format(cmd))
 
